pingus-cvs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Pingus-CVS] r2982 - branches/pingus_sdl/src


From: jsalmon3
Subject: [Pingus-CVS] r2982 - branches/pingus_sdl/src
Date: Fri, 17 Aug 2007 06:33:43 +0200

Author: jsalmon3
Date: 2007-08-17 06:33:30 +0200 (Fri, 17 Aug 2007)
New Revision: 2982

Modified:
   branches/pingus_sdl/src/config.cpp
   branches/pingus_sdl/src/pingu.hpp
   branches/pingus_sdl/src/pingu_action.hpp
   branches/pingus_sdl/src/pingus_main.cpp
   branches/pingus_sdl/src/plf_res_mgr.cpp
Log:
Spelling/grammar fixes

Modified: branches/pingus_sdl/src/config.cpp
===================================================================
--- branches/pingus_sdl/src/config.cpp  2007-08-16 22:43:45 UTC (rev 2981)
+++ branches/pingus_sdl/src/config.cpp  2007-08-17 04:33:30 UTC (rev 2982)
@@ -202,7 +202,7 @@
       if (isspace(atom)){
        return ret_val;
       } else {
-       syntax_error(std::string(_("Unexpected char '")) + atom + "'");
+        syntax_error(std::string(_("Unexpected char: '")) + atom + "'");
       }
     }
 

Modified: branches/pingus_sdl/src/pingu.hpp
===================================================================
--- branches/pingus_sdl/src/pingu.hpp   2007-08-16 22:43:45 UTC (rev 2981)
+++ branches/pingus_sdl/src/pingu.hpp   2007-08-17 04:33:30 UTC (rev 2982)
@@ -198,7 +198,7 @@
 
   double dist (int x, int y);
 
   /** Return true if the pingu can be catched with the mouse and
       another action can be applied, false otherwise (exiter,
       splashed, etc.) */
   bool catchable ();

Modified: branches/pingus_sdl/src/pingu_action.hpp
===================================================================
--- branches/pingus_sdl/src/pingu_action.hpp    2007-08-16 22:43:45 UTC (rev 
2981)
+++ branches/pingus_sdl/src/pingu_action.hpp    2007-08-17 04:33:30 UTC (rev 
2982)
@@ -94,7 +94,7 @@
   /// The time the action needs to get activated (see bomber.cxx)
   virtual int   activation_time () { return -1; };
 
   /** Return true if the pingu can be catched with the mouse and
       another action can be applied, false otherwise (exiter,
       splashed, etc.) */
   virtual bool catchable () { return true; }

Modified: branches/pingus_sdl/src/pingus_main.cpp
===================================================================
--- branches/pingus_sdl/src/pingus_main.cpp     2007-08-16 22:43:45 UTC (rev 
2981)
+++ branches/pingus_sdl/src/pingus_main.cpp     2007-08-17 04:33:30 UTC (rev 
2982)
@@ -97,12 +97,12 @@
     {
     case SIGSEGV:
       
puts("\n,------------------------------------------------------------------------");
-      puts(_("| segfault_handler: catched a SIGSEGV."));
+      puts(_("| segfault_handler: caught a SIGSEGV."));
       puts  ("|");
       puts(_("| Woops, Pingus just crashed, congratulations you've found a 
bug."));
-      puts(_("| Please write a little bug report to <address@hidden>, include 
informations"));
-      puts(_("| where exacly the SIGSEGV occured and how to reproduce it."));
-      puts(_("| Also try include a backtrace, you can get it like this:"));
+      puts(_("| Please write a little bug report to <address@hidden>, include 
information"));
+      puts(_("| where exacly the SIGSEGV occurred and how to reproduce it."));
+      puts(_("| Also try to include a backtrace, you can get it by doing:"));
       puts  ("|");
       puts  ("| $ gdb pingus core");
       puts  ("| (gdb) bt");
@@ -230,13 +230,13 @@
   argp.add_option(363, "font", "FILE",
                   _("Test a font"));
   argp.add_option(364, "language", "LANG",
-                  _("Select language for use with Pingus"));
+                  _("Select language to use with Pingus"));
   argp.add_option(365, "list-languages", "",
                   _("List all available languages"));
   argp.add_option('v', "verbose", "", 
                   _("Print some more messages to stdout, can be set multiple 
times to increase verbosity"));
   argp.add_option('V', "version", "", 
-                  _("Prints version number and exit"));
+                  _("Print version number and exit"));
   argp.add_option(337, "disable-auto-scrolling", "",
                   _("Disable automatic scrolling"));
   argp.add_option(346, "enable-swcursor", "",
@@ -251,10 +251,10 @@
 
   argp.add_group(_("Debugging and experimental stuff:"));
   argp.add_option(334, "maintainer-mode",  "",  
-                  _("Enables some features, only interesting programmers"));
+                  _("Enables some features, only interesting to programmers"));
   argp.add_option(352, "debug",  "OPTION", 
-                  _("Enable the output of debugging infos, possible"
-                    "OPTION's are tiles, gametime, actions, sound, resources, 
gui,"
+                  _("Enable the output of debugging info, possible"
+                    "OPTIONs are tiles, gametime, actions, sound, resources, 
gui,"
                     "input, pathmgr"));
   argp.add_option(354, "min-frame-skip", "N",
                   _("Skip at least N frames, larger values speed the game 
up"));

Modified: branches/pingus_sdl/src/plf_res_mgr.cpp
===================================================================
--- branches/pingus_sdl/src/plf_res_mgr.cpp     2007-08-16 22:43:45 UTC (rev 
2981)
+++ branches/pingus_sdl/src/plf_res_mgr.cpp     2007-08-17 04:33:30 UTC (rev 
2982)
@@ -47,7 +47,7 @@
       plf_map[res_name]  = entry;
 
       // FIXME: leaking pointers to the outsite work is not such a good
-      // idea, could lead to throuble sooner or later
+      // idea, could lead to trouble sooner or later
 
       return PingusLevel (entry.plf);
     }
@@ -68,11 +68,11 @@
           plf_map[res_name]  = entry;
 
           // FIXME: leaking pointers to the outsite work is not such a good
-          // idea, could lead to throuble sooner or later
+          // idea, could lead to trouble sooner or later
           return PingusLevel (entry.plf);
         }
       else
-        { // File in cache is up to date, everything is already, return it
+        { // File in cache is up to date, everything is all ready, return it
           pout(PINGUS_DEBUG_LOADING) << "PLFResMgr: Loading level from CACHE: 
'" << res_name << "' -> '" << filename << "'" << std::endl;
 
@@ -198,7 +198,7 @@
   double dist (int x, int y);
 
-  /** Return true if the pingu can be catched with the mouse and
+  /** Return true if the pingu can be caught with the mouse and
       another action can be applied, false otherwise (exiter,
       splashed, etc.) */
@@ -94,7 +94,7 @@
   virtual int   activation_time () { return -1; };
 
-  /** Return true if the pingu can be catched with the mouse and
+  /** Return true if the pingu can be caught with the mouse and
       another action can be applied, false otherwise (exiter,
       splashed, etc.) */
           return i->second.plf;





reply via email to

[Prev in Thread] Current Thread [Next in Thread]